http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/681cad66/install/installer/trafodion_install
----------------------------------------------------------------------
diff --git a/install/installer/trafodion_install 
b/install/installer/trafodion_install
index 1d9a43e..7fc13dd 100755
--- a/install/installer/trafodion_install
+++ b/install/installer/trafodion_install
@@ -68,7 +68,7 @@ function removePassword {
 
  $TRAF_PDSH sudo chmod 777 $TRAF_CONFIG
  $TRAF_PDSH sudo sed -i '/TRAF_USER_PASSWORD\=/d' $TRAF_CONFIG
- $TRAF_PDSH sudo sed -i '/PASSWORD\=/d' $TRAF_CONFIG
+ $TRAF_PDSH sudo sed -i '/\<PASSWORD\>/d' $TRAF_CONFIG
  $TRAF_PDSH sudo chmod 777 $TRAF_CONFIG
 
 }
@@ -93,7 +93,6 @@ do
    if [[ $hbaseInstalled -eq "1" ]]; then
 
       version=$(ssh -q -n $node grep "Version" $HOME/hbaseVersion.txt | sed 
's/-.*//' | awk {'print$2'})
-
       if [[ $HADOOP_TYPE == "hortonworks" ]]; then
          if [[ $CDH_5_3_HDP_2_2_SUPPORT == "N" ]]; then
             if [[ "$HDP_2_3_SUPPORT" == "N" ]]; then
@@ -103,12 +102,11 @@ do
                   exit -1
                fi
             else
-               supportedHBase=${version:0:3} 
-               if [[ $supportedHBase -ne "1.1" ]]; then
-                  echo "***ERROR: HBase installed must be 1.1.x on node $node"
+               supportedHBase=$(echo $version | grep "1.1.2" | wc -l)
+               if [[ $supportedHBase -eq "0" ]]; then
+                  echo "***ERROR: HBase installed must be 1.1.2 on node $node"
                   exit -1
                fi
-               
             fi
          else
             supportedHBase=$(echo $version | grep "0.98.4" | wc -l)
@@ -120,12 +118,18 @@ do
       fi
       if [[ $HADOOP_TYPE == "cloudera" ]]; then
          if [[ $CDH_5_3_HDP_2_2_SUPPORT == "N" ]]; then
-            if [[ $CDH_5_4_SUPPORT == "Y" ]]; then
+            if [[ $CDH_5_4_SUPPORT == "Y" ]] || [[ $CDH_5_5_SUPPORT == "Y" ]]; 
then
                supportedHBase=$(echo $version | grep "1.0.0" | wc -l)
                if [[ $supportedHBase -eq "0" ]]; then
                   echo "***ERROR: HBase installed must be 1.0.0 on node $node"
                   exit -1
                fi
+               cdhVersion=$(ssh -q -n $node grep "Version" 
$HOME/hbaseVersion.txt | grep "cdh5.4.*" | wc -l)
+               if [[ "$cdhVersion" -ge "1" ]]; then
+                  CDH_VERSION="5.4"
+               else
+                  CDH_VERSION="5.5"
+               fi
             else
                supportedHBase=$(echo $version | grep "0.98.1" | wc -l)
                if [[ $supportedHBase -eq "0" ]]; then
@@ -140,6 +144,7 @@ do
                exit -1
             fi
          fi
+
       fi
       hbaseVersion=$(ssh -q -n $node grep "Version" $HOME/hbaseVersion.txt | 
sed 's/-.*//' | awk {'print$2'})
       break
@@ -155,6 +160,8 @@ sed -i '/hbaseVersion\=/d' $TRAF_CONFIG
 echo "export hbaseVersion=\"$hbaseVersion\"" >> $TRAF_CONFIG
 sed -i '/HBASE\=/d' $TRAF_CONFIG
 echo "export HBASE=\"$HBASE\"" >> $TRAF_CONFIG
+sed -i '/CDH_VERSION\=/d' $TRAF_CONFIG
+echo "export CDH_VERSION=\"$CDH_VERSION\"" >> $TRAF_CONFIG
 sudo chmod 777 $TRAF_CONFIG
 sudo rm -rf hbaseVersion.txt
 
@@ -248,6 +255,14 @@ export TRAF_CONFIG_FILE=$(basename $TRAF_CONFIG)
 export TRAF_USER="trafodion"
 #==============================================
 #Prechecks 
+#Check if HBase is up
+
+#$LOCAL_WORKDIR/checkHBase
+
+#if [[ "$?" -ne "0" ]]; then
+#   exit -1
+#fi
+
 
 #Check not installing as userid Trafodion
 if [[ "$(whoami)" == "$TRAF_USER" ]]; then
@@ -525,7 +540,6 @@ source $TRAF_CONFIG
 #Check to make sure HBase Version is the correct version
 
 checkHBaseVersion
-
 #==============================================
 # Determine Trafodion version by parsing it
 # from the trafodion_server tar file.
@@ -551,60 +565,9 @@ TRAF_VERSION=$(echo $traf_version | sed -e 
's@\([0-9*].*\)-debug@\1@')
 
 # Detect java version
 
-for node in $HADOOP_NODES
-do
-   java_exec=$(ssh -q -n $node ps -C java --noheader -o pid,user,cmd \
-      | grep --max-count=1 " hbase" \
-      | awk '{print $3}' )
-   echo "***DEBUG: HBase's java_exec=$java_exec"
-   if [ ! -z $java_exec ]; then
-      JAVA_VERSION=$(ssh -q -n $node $java_exec -version 2>&1)
-      break;
-      echo "***ERROR: Unable to determine HBase's Java version"
-      echo "***ERROR: Check that HBase is up on node $HOSTNAME"
-      exit -1
-   fi
-done 
-
-if [[ -z $JAVA_VERSION ]]; then
-   echo "***ERROR: Unable to determine HBase's Java version"
-   echo "***ERROR: Check that HBase is up on $CLUSTER_NAME"
-   exit -1
-else
-   JAVA_VERSION=$(echo $JAVA_VERSION \
-      | grep version \
-      | awk '{print $3}' \
-      | sed -e 's@"@@g')
-fi
-
-# test for java 1.7
-java_17=$(echo $JAVA_VERSION | grep "1.7." | wc -l)
-java_18=$(echo $JAVA_VERSION | grep "1.8." | wc -l)
-
-# if not java 1.7 then test for java 1.6
-if [ "$java_17" == "0" ] && [ "$java_18" == "0" ]; then
-   java_16=$(echo $JAVA_VERSION | grep "1.6." | wc -l)
-
-   # if not 1.7 nor 1.6 then we have a problem
-   if [ "$java_16" == "0" ]; then
-      echo "***ERROR: Unsupported HBase java version.  HBase java version must 
be 1.6 or 1.7"
-      exit -1
-   else
-      JAVA_VERSION="1.6"
-   fi
-else
-   if [[ $java_17 == "0" ]]; then
-      JAVA_VERSION="1.8"
-   else
-      JAVA_VERSION="1.7"
-   fi
-fi
-
 sudo chmod 777 $TRAF_CONFIG
 sed -i '/TRAF_VERSION\=/d' $TRAF_CONFIG
 echo "export TRAF_VERSION=\"$TRAF_VERSION\"" >> $TRAF_CONFIG
-sed -i '/JAVA_VERSION\=/d' $TRAF_CONFIG
-echo "export JAVA_VERSION=\"$JAVA_VERSION\"" >> $TRAF_CONFIG
 sudo chmod 777 $TRAF_CONFIG
 #==============================================
 # Run trafodion_setup
@@ -665,7 +628,6 @@ $TRAF_PDSH sudo chmod 777 $LOCAL_WORKDIR
 copyConfig
 fixPermissions
 
-
 $LOCAL_WORKDIR/traf_sqconfig
 if [ $? != 0 ]; then
    echo "***ERROR: traf_sqconfig script failed."
@@ -767,6 +729,7 @@ if [[ "$LDAP_SECURITY" == "Y" ]]; then
       fi
    fi
 fi
+
 #=============================================
 #Run trafodion_mods
 
@@ -804,6 +767,8 @@ fi
 
 echo "***INFO: Trafodion Mods ran successfully."
 
+#Get HBaseSite.xml information 
+$LOCAL_WORKDIR/parseHBaseSite.py
 #==============================================
 #Install Trafodion
 echo
@@ -841,7 +806,6 @@ if [[ $START_ALL == "Y" ]]; then
      exit -1
   fi
 fi
-
 #==============================================
 MODS_COMPLETE="N"
 sudo chmod 777 $TRAF_CONFIG

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/681cad66/install/traf_tools_setup.sh
----------------------------------------------------------------------
diff --git a/licenses/lic-clients-bin b/licenses/lic-clients-bin
index 8e3b96a..ff9b503 100644
--- a/licenses/lic-clients-bin
+++ b/licenses/lic-clients-bin
@@ -1,7 +1,6 @@
 ===============================================================================
 The binary distribution of Apache Trafodion bundles OpenSSL software. 
Specifically,
-the Linux ODBC driver is statically linked with OpenSSL libraries. The Windows
-ODBC driver (TFODBC64) also links in OpenSSL libraries.
+the Linux ODBC driver is statically linked with OpenSSL libraries. 
 
 OpenSSL is available under a BSD like license. (http://www.openssl.org/)
 
@@ -167,33 +166,3 @@ MIT like license. (http://site.icu-project.org/)
   this Software without prior written authorization of the copyright holder.
 
 +++++++++++++++++++++++++++++
-
-The binary distribution of Apache Trafodion bundles zlib software. 
Specifically,
-the Windows ODBC driver (TFODBC64) links in zlib libraries. Zlib is 
-available under the zlib/libpng license.
-
-  zlib.h -- interface of the 'zlib' general purpose compression library
-  version 1.2.8, April 28th, 2013
-
-  Copyright (C) 1995-2013 Jean-loup Gailly and Mark Adler
-
-  This software is provided 'as-is', without any express or implied
-  warranty.  In no event will the authors be held liable for any damages
-  arising from the use of this software.
-
-  Permission is granted to anyone to use this software for any purpose,
-  including commercial applications, and to alter it and redistribute it
-  freely, subject to the following restrictions:
-
-  1. The origin of this software must not be misrepresented; you must not
-     claim that you wrote the original software. If you use this software
-     in a product, an acknowledgment in the product documentation would be
-     appreciated but is not required.
-  2. Altered source versions must be plainly marked as such, and must not be
-     misrepresented as being the original software.
-  3. This notice may not be removed or altered from any source distribution.
-
-  Jean-loup Gailly        Mark Adler
-  [email protected]          [email protected]
-
-+++++++++++++++++++++++++++++

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/681cad66/licenses/lic-dcs-bin
----------------------------------------------------------------------
diff --git a/licenses/lic-dcs-bin b/licenses/lic-dcs-bin
index fdd52ed..96a489d 100644
--- a/licenses/lic-dcs-bin
+++ b/licenses/lic-dcs-bin
@@ -1,9 +1,652 @@
 ===============================================================================
-To Do:
+The binary distribution of Apache Trafodion DCS bundles Jetty software which is
+available under the Apache License Version 2.0 (ALv2), though developed outside
+of the ASF.  The bundled software includes Jetty Server, Jetty Utilities, and
+Glassfish Jasper API (JSP2.1 API).  http://www.eclipse.org/jetty/
+
++++++++++++++++++++++++++++++
+
+The binary distribution of Apache Trafodion DCS bundles SLF4J (Simple Logging
+Facade for Java) software which is available under the MIT/X11 License.
+http://www.slf4j.org
+
+ Copyright (c) 2004-2013 QOS.ch
+ All rights reserved.
+
+ Permission is hereby granted, free  of charge, to any person obtaining
+ a  copy  of this  software  and  associated  documentation files  (the
+ "Software"), to  deal in  the Software without  restriction, including
+ without limitation  the rights to  use, copy, modify,  merge, publish,
+ distribute,  sublicense, and/or sell  copies of  the Software,  and to
+ permit persons to whom the Software  is furnished to do so, subject to
+ the following conditions:
+
+ The  above  copyright  notice  and  this permission  notice  shall  be
+ included in all copies or substantial portions of the Software.
+
+ THE  SOFTWARE IS  PROVIDED  "AS  IS", WITHOUT  WARRANTY  OF ANY  KIND,
+ EXPRESS OR  IMPLIED, INCLUDING  BUT NOT LIMITED  TO THE  WARRANTIES OF
+ MERCHANTABILITY,    FITNESS    FOR    A   PARTICULAR    PURPOSE    AND
+ NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
+ LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
+ OF CONTRACT, TORT OR OTHERWISE,  ARISING FROM, OUT OF OR IN CONNECTION
+ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
++++++++++++++++++++++++++++++
+
+The binary distribution of Apache Trafodion DCS bundles Display Tag Library
+software which is available under the Artistic License.
+http://displaytag.sf.net
+
+ The Artistic License
+
+ Preamble
+
+  The intent of this document is to state the conditions under which a
+  Package may be copied, such that the Copyright Holder maintains some
+  semblance of artistic control over the development of the package,
+  while giving the users of the package the right to use and distribute
+  the Package in a more-or-less customary fashion, plus the right to make
+  reasonable modifications.
+
+    "Package" refers to the collection of files distributed by the
+    Copyright Holder, and derivatives of that collection of files
+    created through textual modification.
+
+    "Standard Version" refers to such a Package if it has not been
+    modified, or has been modified in accordance with the wishes
+    of the Copyright Holder.
+
+    "Copyright Holder" is whoever is named in the copyright or
+    copyrights for the package.
+
+    "You" is you, if you're thinking about copying or distributing
+    this Package.
+
+    "Reasonable copying fee" is whatever you can justify on the
+    basis of media cost, duplication charges, time of people involved,
+    and so on.  (You will not be required to justify it to the
+    Copyright Holder, but only to the computing community at large
+    as a market that must bear the fee.)
+
+    "Freely Available" means that no fee is charged for the item
+    itself, though there may be fees involved in handling the item.
+    It also means that recipients of the item may redistribute it
+    under the same conditions they received it.
+
+
+  1. You may make and give away verbatim copies of the source form of the
+  Standard Version of this Package without restriction, provided that you
+  duplicate all of the original copyright notices and associated disclaimers.
+
+
+  2. You may apply bug fixes, portability fixes and other modifications
+  derived from the Public Domain or from the Copyright Holder.  A Package
+  modified in such a way shall still be considered the Standard Version.
+
+
+  3. You may otherwise modify your copy of this Package in any way, provided
+  that you insert a prominent notice in each changed file stating how and
+  when you changed that file, and provided that you do at least ONE of the
+  following:
+
+    a) place your modifications in the Public Domain or otherwise make them
+      Freely Available, such as by posting said modifications to Usenet or
+      an equivalent medium, or placing the modifications on a major archive
+      site such as ftp.uu.net, or by allowing the Copyright Holder to include
+      your modifications in the Standard Version of the Package.
+
+    b) use the modified Package only within your corporation or organization.
+
+    c) rename any non-standard executables so the names do not conflict
+      with standard executables, which must also be provided, and provide
+      a separate manual page for each non-standard executable that clearly
+      documents how it differs from the Standard Version.
+
+    d) make other distribution arrangements with the Copyright Holder.
+
+
+  4. You may distribute the programs of this Package in object code or
+  executable form, provided that you do at least ONE of the following:
+
+    a) distribute a Standard Version of the executables and library files,
+      together with instructions (in the manual page or equivalent) on where
+      to get the Standard Version.
+
+    b) accompany the distribution with the machine-readable source of
+      the Package with your modifications.
+
+    c) accompany any non-standard executables with their corresponding
+      Standard Version executables, giving the non-standard executables
+      non-standard names, and clearly documenting the differences in manual
+      pages (or equivalent), together with instructions on where to get
+      the Standard Version.
+
+    d) make other distribution arrangements with the Copyright Holder.
+
+
+  5. You may charge a reasonable copying fee for any distribution of this
+  Package.  You may charge any fee you choose for support of this Package.
+  You may not charge a fee for this Package itself.  However,
+  you may distribute this Package in aggregate with other (possibly
+  commercial) programs as part of a larger (possibly commercial) software
+  distribution provided that you do not advertise this Package as a
+  product of your own.
+
+
+  6. The scripts and library files supplied as input to or produced as
+  output from the programs of this Package do not automatically fall
+  under the copyright of this Package, but belong to whomever generated
+  them, and may be sold commercially, and may be aggregated with this
+  Package.
+
+
+  7. C or perl subroutines supplied by you and linked into this Package
+  shall not be considered part of this Package.
+
+
+  8. The name of the Copyright Holder may not be used to endorse or promote
+  products derived from this software without specific prior written 
permission.
+
+
+  9. THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
+  IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
+  WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+
+
+  The End
+
++++++++++++++++++++++++++++++
+
+The binary distribution of Apache Trafodion DCS bundles Jython Standalone
+software which is available under the Python Software License.
+http://www.jython.org
+
+  ====================================
+  The Jython License
+  ====================================
+
+
+  A. TERMS AND CONDITIONS FOR ACCESSING OR OTHERWISE USING JYTHON
+  
==============================================================================================================
+
+  PYTHON SOFTWARE FOUNDATION LICENSE VERSION 2
+  
----------------------------------------------------------------------------------------
+
+  1. This LICENSE AGREEMENT is between the Python Software Foundation
+  ("PSF"), and the Individual or Organization ("Licensee") accessing and
+  otherwise using this software ("Jython") in source or binary form and
+  its associated documentation.
+
+  2. Subject to the terms and conditions of this License Agreement, PSF
+  hereby grants Licensee a nonexclusive, royalty-free, world-wide
+  license to reproduce, analyze, test, perform and/or display publicly,
+  prepare derivative works, distribute, and otherwise use Jython alone
+  or in any derivative version, provided, however, that PSF's License
+  Agreement and PSF's notice of copyright, i.e., "Copyright (c) 2007
+  Python Software Foundation; All Rights Reserved" are retained in
+  Jython alone or in any derivative version prepared by Licensee.
+
+  3. In the event Licensee prepares a derivative work that is based on
+  or incorporates Jython or any part thereof, and wants to make
+  the derivative work available to others as provided herein, then
+  Licensee hereby agrees to include in any such work a brief summary of
+  the changes made to Jython.
+
+  4. PSF is making Jython available to Licensee on an "AS IS"
+  basis.  PSF MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR
+  IMPLIED.  BY WAY OF EXAMPLE, BUT NOT LIMITATION, PSF MAKES NO AND
+  DISCLAIMS ANY REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS
+  FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF JYTHON WILL NOT
+  INFRINGE ANY THIRD PARTY RIGHTS.
+
+  5. PSF SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF JYTHON
+  FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR LOSS AS
+  A RESULT OF MODIFYING, DISTRIBUTING, OR OTHERWISE USING JYTHON,
+  OR ANY DERIVATIVE THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF.
+
+  6. This License Agreement will automatically terminate upon a material
+  breach of its terms and conditions.
+
+  7. Nothing in this License Agreement shall be deemed to create any
+  relationship of agency, partnership, or joint venture between PSF and
+  Licensee.  This License Agreement does not grant permission to use PSF
+  trademarks or trade name in a trademark sense to endorse or promote
+  products or services of Licensee, or any third party.
+
+  8. By copying, installing or otherwise using Jython, Licensee
+  agrees to be bound by the terms and conditions of this License
+  Agreement.
+
+  Jython 2.0, 2.1 License
+  --------------------------------------------
+
+  Copyright (c) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Jython 
Developers
+  All rights reserved.
+
+  Redistribution and use in source and binary forms, with or without
+  modification, are permitted provided that the following conditions
+  are met:
+
+   - Redistributions of source code must retain the above copyright
+     notice, this list of conditions and the following disclaimer.
+
+   - Redistributions in binary form must reproduce the above copyright
+     notice, this list of conditions and the following disclaimer in
+     the documentation and/or other materials provided with the distribution.
+
+   - Neither the name of the Jython Developers nor the names of
+     its contributors may be used to endorse or promote products
+     derived from this software without specific prior written permission.
+
+  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+  "AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR
+  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
+  OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
 
-Need to investigate and document licenses for software bundled in:
 
-dcs-2.0.0.jar
-lib/*.jar
+
+  JPython 1.1.x Software License.
+  ______________________________________________________________________
+
+    1. This LICENSE AGREEMENT is between the Corporation for National Research
+       Initiatives, having an office at 1895 Preston White Drive, Reston, VA
+       20191 ("CNRI"), and the Individual or Organization ("Licensee")
+       accessing and using JPython version 1.1.x in source or binary form and
+       its associated documentation as provided herein ("Software").
+
+    2. Subject to the terms and conditions of this License Agreement, CNRI
+       hereby grants Licensee a non-exclusive, non-transferable, royalty-free,
+       world-wide license to reproduce, analyze, test, perform and/or display
+       publicly, prepare derivative works, distribute, and otherwise use the
+       Software alone or in any derivative version, provided, however, that
+       CNRI's License Agreement and CNRI's notice of copyright, i.e.,
+       "Copyright �1996-1999 Corporation for National Research 
Initiatives;
+       All Rights Reserved" are both retained in the Software, alone or in any
+       derivative version prepared by Licensee.
+
+       Alternatively, in lieu of CNRI's License Agreement, Licensee may
+       substitute the following text (omitting the quotes), provided, however,
+       that such text is displayed prominently in the Software alone or in any
+       derivative version prepared by Licensee: "JPython (Version 1.1.x) is
+       made available subject to the terms and conditions in CNRI's License
+       Agreement. This Agreement may be located on the Internet using the
+       following unique, persistent identifier (known as a handle):
+       1895.22/1006. The License may also be obtained from a proxy server on
+       the Web using the following URL: http://hdl.handle.net/1895.22/1006.";
+
+    3. In the event Licensee prepares a derivative work that is based on or
+       incorporates the Software or any part thereof, and wants to make the
+       derivative work available to the public as provided herein, then
+       Licensee hereby agrees to indicate in any such work, in a prominently
+       visible way, the nature of the modifications made to CNRI's Software.
+
+    4. Licensee may not use CNRI trademarks or trade name, including JPython
+       or CNRI, in a trademark sense to endorse or promote products or
+       services of Licensee, or any third party. Licensee may use the mark
+       JPython in connection with Licensee's derivative versions that are
+       based on or incorporate the Software, but only in the form
+       "JPython-based ___________________," or equivalent.
+
+    5. CNRI is making the Software available to Licensee on an "AS IS" basis.
+       CNRI MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED. BY WAY
+       OF EXAMPLE, BUT NOT LIMITATION, CNRI MAKES NO AND DISCLAIMS ANY
+       REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS FOR ANY
+       PARTICULAR PURPOSE OR THAT THE USE OF THE SOFTWARE WILL NOT INFRINGE
+       ANY THIRD PARTY RIGHTS.
+
+    6. CNRI SHALL NOT BE LIABLE TO LICENSEE OR OTHER USERS OF THE SOFTWARE FOR
+       ANY INCIDENTAL, SPECIAL OR CONSEQUENTIAL DAMAGES OR LOSS AS A RESULT OF
+       USING, MODIFYING OR DISTRIBUTING THE SOFTWARE, OR ANY DERIVATIVE
+       THEREOF, EVEN IF ADVISED OF THE POSSIBILITY THEREOF. SOME STATES DO NOT
+       ALLOW THE LIMITATION OR EXCLUSION OF LIABILITY SO THE ABOVE DISCLAIMER
+       MAY NOT APPLY TO LICENSEE.
+
+    7. This License Agreement may be terminated by CNRI (i) immediately upon
+       written notice from CNRI of any material breach by the Licensee, if the
+       nature of the breach is such that it cannot be promptly remedied; or
+       (ii) sixty (60) days following notice from CNRI to Licensee of a
+       material remediable breach, if Licensee has not remedied such breach
+       within that sixty-day period.
+
+    8. This License Agreement shall be governed by and interpreted in all
+       respects by the law of the State of Virginia, excluding conflict of law
+       provisions. Nothing in this Agreement shall be deemed to create any
+       relationship of agency, partnership, or joint venture between CNRI and
+       Licensee.
+
+    9. By clicking on the "ACCEPT" button where indicated, or by installing,
+       copying or otherwise using the Software, Licensee agrees to be bound by
+       the terms and conditions of this License Agreement.
+
+                                 [ACCEPT BUTTON]
+
+  B. HISTORY OF THE SOFTWARE
+  =======================================================
+
+  JPython was created in late 1997 by Jim Hugunin. Jim was also the
+  primary developer while he was at CNRI. In February 1999 Barry Warsaw
+  took over as primary developer and released JPython version 1.1.
+
+  In October 2000 Barry helped move the software to SourceForge
+  where it was renamed to Jython. Jython 2.0 and 2.1 were developed
+  under the Jython specific license below.
+
+  From the 2.2 release on, Jython contributors have signed
+  Python Software Foundation contributor agreements and releases are
+  covered under the Python Software Foundation license version 2.
+
+  The standard library is covered by the Python Software Foundation
+  license as well. See the Lib/LICENSE file for details.
+
+  The zxJDBC package was written by Brian Zimmer and originally licensed
+  under the GNU Public License.  The package is now covered by the Jython
+  Software License.
+
+  The command line interpreter is covered by the Apache Software
+  License.  See the org/apache/LICENSE file for details.
+
++++++++++++++++++++++++++++++
+
+The binary distribution of Apache Trafodion DCS bundles Glassfish Jasper 2.1
+and Servlet Specification 2.5 API software which is available under the
+CDDL License.
+https://glassfish.dev.java.net
+https://glassfish.dev.java.net/public/CDDLv1.0.html
+
+  COMMON DEVELOPMENT AND DISTRIBUTION LICENSE (CDDL) Version 1.0 1.
+
+  Definitions.
+
+  1.1. Contributor means each individual or entity that creates or contributes
+  to the creation of Modifications.
+
+  1.2. Contributor Version means the combination of the Original Software,
+  prior Modifications used by a Contributor (if any), and the Modifications 
made
+  by that particular Contributor.
+
+  1.3. Covered Software means (a) the Original Software, or (b) Modifications,
+  or (c) the combination of files containing Original Software with files
+  containing Modifications, in each case including portions thereof.
+
+  1.4. Executable means the Covered Software in any form other than Source 
Code.
+
+  1.5. Initial Developer means the individual or entity that first makes
+  Original Software available under this License.
+
+  1.6. Larger Work means a work which combines Covered Software or portions
+  thereof with code not governed by the terms of this License.
+
+  1.7. License means this document.
+
+  1.8. Licensable means having the right to grant, to the maximum extent
+  possible, whether at the time of the initial grant or subsequently acquired,
+  any and all of the rights conveyed herein.
+
+  1.9. Modifications means the Source Code and Executable form of any of the
+  following: A. Any file that results from an addition to, deletion from or
+  modification of the contents of a file containing Original Software or 
previous
+  Modifications; B. Any new file that contains any part of the Original 
Software
+  or previous Modification; or C. Any new file that is contributed or otherwise
+  made available under the terms of this License.
+
+  1.10. Original Software means the Source Code and Executable form of computer
+  software code that is originally released under this License.
+
+  1.11. Patent Claims means any patent claim(s), now owned or hereafter
+  acquired, including without limitation, method, process, and apparatus 
claims,
+  in any patent Licensable by grantor.
+
+  1.12. Source Code means (a) the common form of computer software code in
+  which modifications are made and (b) associated documentation included in or
+  with such code.
+
+  1.13. You (or Your) means an individual or a legal entity exercising rights
+  under, and complying with all of the terms of, this License. For legal
+  entities, You includes any entity which controls, is controlled by, or is 
under
+  common control with You. For purposes of this definition, control means (a) 
the
+  power, direct or indirect, to cause the direction or management of such 
entity,
+  whether by contract or otherwise, or (b) ownership of more than fifty percent
+  (50%) of the outstanding shares or beneficial ownership of such entity.
+
+  2. License Grants.
+
+   2.1. The Initial Developer Grant. Conditioned upon Your compliance with
+   Section 3.1 below and subject to third party intellectual property claims, 
the
+   Initial Developer hereby grants You a world-wide, royalty-free, 
non-exclusive
+   license:
+
+  (a) under intellectual property rights (other than patent or trademark)
+  Licensable by Initial Developer, to use, reproduce, modify, display, perform,
+  sublicense and distribute the Original Software (or portions thereof), with 
or
+  without Modifications, and/or as part of a Larger Work; and
+
+  (b) under Patent Claims infringed by the making, using or selling of Original
+  Software, to make, have made, use, practice, sell, and offer for sale, and/or
+  otherwise dispose of the Original Software (or portions thereof);
+
+  (c) The licenses granted in Sections 2.1(a) and (b) are effective on the
+  date Initial Developer first distributes or otherwise makes the Original
+  Software available to a third party under the terms of this License;
+
+  (d) Notwithstanding Section 2.1(b) above, no patent license is granted: (1)
+  for code that You delete from the Original Software, or (2) for infringements
+  caused by: (i) the modification of the Original Software, or (ii) the
+  combination of the Original Software with other software or devices.
+
+  2.2. Contributor Grant. Conditioned upon Your compliance with Section 3.1
+  below and subject to third party intellectual property claims, each 
Contributor
+  hereby grants You a world-wide, royalty-free, non-exclusive license:
+
+  (a) under intellectual property rights (other than patent or trademark)
+  Licensable by Contributor to use, reproduce, modify, display, perform,
+  sublicense and distribute the Modifications created by such Contributor (or
+  portions thereof), either on an unmodified basis, with other Modifications, 
as
+  Covered Software and/or as part of a Larger Work; and
+
+  (b) under Patent Claims infringed by the making, using, or selling of
+  Modifications made by that Contributor either alone and/or in combination 
with
+  its Contributor Version (or portions of such combination), to make, use, 
sell,
+  offer for sale, have made, and/or otherwise dispose of: (1) Modifications 
made
+  by that Contributor (or portions thereof); and (2) the combination of
+  Modifications made by that Contributor with its Contributor Version (or
+  portions of such combination).
+
+  (c) The licenses granted in Sections 2.2(a) and 2.2(b) are effective on the
+  date Contributor first distributes or otherwise makes the Modifications
+  available to a third party.
+
+  (d) Notwithstanding Section 2.2(b) above, no patent license is granted: (1)
+  for any code that Contributor has deleted from the Contributor Version; (2) 
for
+  infringements caused by: (i) third party modifications of Contributor 
Version,
+  or (ii) the combination of Modifications made by that Contributor with other
+  software (except as part of the Contributor Version) or other devices; or (3)
+  under Patent Claims infringed by Covered Software in the absence of
+  Modifications made by that Contributor.
+
+  3. Distribution Obligations.
+
+  3.1. Availability of Source Code. Any Covered Software that You distribute or
+  otherwise make available in Executable form must also be made available in
+  Source Code form and that Source Code form must be distributed only under the
+  terms of this License. You must include a copy of this License with every 
copy
+  of the Source Code form of the Covered Software You distribute or otherwise
+  make available. You must inform recipients of any such Covered Software in
+  Executable form as to how they can obtain such Covered Software in Source 
Code
+  form in a reasonable manner on or through a medium customarily used for
+  software exchange.
+
+  3.2. Modifications. The Modifications that You create or to which You
+  contribute are governed by the terms of this License. You represent that You
+  believe Your Modifications are Your original creation(s) and/or You have
+  sufficient rights to grant the rights conveyed by this License.
+
+  3.3. Required Notices. You must include a notice in each of Your
+  Modifications that identifies You as the Contributor of the Modification. You
+  may not remove or alter any copyright, patent or trademark notices contained
+  within the Covered Software, or any notices of licensing or any descriptive
+  text giving attribution to any Contributor or the Initial Developer.
+
+  3.4. Application of Additional Terms. You may not offer or impose any terms
+  on any Covered Software in Source Code form that alters or restricts the
+  applicable version of this License or the recipients rights hereunder. You 
may
+  choose to offer, and to charge a fee for, warranty, support, indemnity or
+  liability obligations to one or more recipients of Covered Software. However,
+  you may do so only on Your own behalf, and not on behalf of the Initial
+  Developer or any Contributor. You must make it absolutely clear that any such
+  warranty, support, indemnity or liability obligation is offered by You alone,
+  and You hereby agree to indemnify the Initial Developer and every Contributor
+  for any liability incurred by the Initial Developer or such Contributor as a
+  result of warranty, support, indemnity or liability terms You offer.
+
+  3.5. Distribution of Executable Versions. You may distribute the Executable
+  form of the Covered Software under the terms of this License or under the 
terms
+  of a license of Your choice, which may contain terms different from this
+  License, provided that You are in compliance with the terms of this License 
and
+  that the license for the Executable form does not attempt to limit or alter 
the
+  recipients rights in the Source Code form from the rights set forth in this
+  License. If You distribute the Covered Software in Executable form under a
+  different license, You must make it absolutely clear that any terms which
+  differ from this License are offered by You alone, not by the Initial 
Developer
+  or Contributor. You hereby agree to indemnify the Initial Developer and every
+  Contributor for any liability incurred by the Initial Developer or such
+  Contributor as a result of any such terms You offer.
+
+  3.6. Larger Works. You may create a Larger Work by combining Covered Software
+  with other code not governed by the terms of this License and distribute the
+  Larger Work as a single product. In such a case, You must make sure the
+  requirements of this License are fulfilled for the Covered Software.
+
+  4. Versions of the License.
+
+  4.1. New Versions. Sun Microsystems, Inc. is the initial license steward and
+  may publish revised and/or new versions of this License from time to time. 
Each
+  version will be given a distinguishing version number. Except as provided in
+  Section 4.3, no one other than the license steward has the right to modify 
this
+  License.
+
+  4.2. Effect of New Versions. You may always continue to use, distribute or
+  otherwise make the Covered Software available under the terms of the version 
of
+  the License under which You originally received the Covered Software. If the
+  Initial Developer includes a notice in the Original Software prohibiting it
+  from being distributed or otherwise made available under any subsequent 
version
+  of the License, You must distribute and make the Covered Software available
+  under the terms of the version of the License under which You originally
+  received the Covered Software. Otherwise, You may also choose to use,
+  distribute or otherwise make the Covered Software available under the terms 
of
+  any subsequent version of the License published by the license steward.
+
+  4.3. Modified Versions. When You are an Initial Developer and You want to
+  create a new license for Your Original Software, You may create and use a
+  modified version of this License if You: (a) rename the license and remove 
any
+  references to the name of the license steward (except to note that the 
license
+  differs from this License); and (b) otherwise make it clear that the license
+  contains terms which differ from this License.
+
+  5. DISCLAIMER OF WARRANTY. COVERED SOFTWARE IS PROVIDED UNDER THIS LICENSE ON
+  AN AS IS BASIS, WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED,
+  INCLUDING, WITHOUT LIMITATION, WARRANTIES THAT THE COVERED SOFTWARE IS FREE 
OF
+  DEFECTS, MERCHANTABLE, FIT FOR A PARTICULAR PURPOSE OR NON-INFRINGING. THE
+  ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE COVERED SOFTWARE IS WITH
+  YOU. SHOULD ANY COVERED SOFTWARE PROVE DEFECTIVE IN ANY RESPECT, YOU (NOT THE
+  INITIAL DEVELOPER OR ANY OTHER CONTRIBUTOR) ASSUME THE COST OF ANY NECESSARY
+  SERVICING, REPAIR OR CORRECTION. THIS DISCLAIMER OF WARRANTY CONSTITUTES AN
+  ESSENTIAL PART OF THIS LICENSE. NO USE OF ANY COVERED SOFTWARE IS AUTHORIZED
+  HEREUNDER EXCEPT UNDER THIS DISCLAIMER.
+
+  6. TERMINATION.
+
+  6.1. This License and the rights granted hereunder will terminate
+  automatically if You fail to comply with terms herein and fail to cure such
+  breach within 30 days of becoming aware of the breach. Provisions which, by
+  their nature, must remain in effect beyond the termination of this License
+  shall survive.
+
+  6.2. If You assert a patent infringement claim (excluding declaratory
+  judgment actions) against Initial Developer or a Contributor (the Initial
+  Developer or Contributor against whom You assert such claim is referred to as
+  Participant) alleging that the Participant Software (meaning the Contributor
+  Version where the Participant is a Contributor or the Original Software where
+  the Participant is the Initial Developer) directly or indirectly infringes 
any
+  patent, then any and all rights granted directly or indirectly to You by such
+  Participant, the Initial Developer (if the Initial Developer is not the
+  Participant) and all Contributors under Sections 2.1 and/or 2.2 of this 
License
+  shall, upon 60 days notice from Participant terminate prospectively and
+  automatically at the expiration of such 60 day notice period, unless if 
within
+  such 60 day period You withdraw Your claim with respect to the Participant
+  Software against such Participant either unilaterally or pursuant to a 
written
+  agreement with Participant.
+
+  6.3. In the event of termination under Sections 6.1 or 6.2 above, all end
+  user licenses that have been validly granted by You or any distributor
+  hereunder prior to termination (excluding licenses granted to You by any
+  distributor) shall survive termination.
+
+  7. LIMITATION OF LIABILITY. UNDER NO CIRCUMSTANCES AND UNDER NO LEGAL THEORY,
+  WHETHER TORT (INCLUDING NEGLIGENCE), CONTRACT, OR OTHERWISE, SHALL YOU, THE
+  INITIAL DEVELOPER, ANY OTHER CONTRIBUTOR, OR ANY DISTRIBUTOR OF COVERED
+  SOFTWARE, OR ANY SUPPLIER OF ANY OF SUCH PARTIES, BE LIABLE TO ANY PERSON FOR
+  ANY INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES OF ANY CHARACTER
+  INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOST PROFITS, LOSS OF GOODWILL, 
WORK
+  STOPPAGE, COMPUTER FAILURE OR MALFUNCTION, OR ANY AND ALL OTHER COMMERCIAL
+  DAMAGES OR LOSSES, EVEN IF SUCH PARTY SHALL HAVE BEEN INFORMED OF THE
+  POSSIBILITY OF SUCH DAMAGES. THIS LIMITATION OF LIABILITY SHALL NOT APPLY TO
+  LIABILITY FOR DEATH OR PERSONAL INJURY RESULTING FROM SUCH PARTYS NEGLIGENCE 
TO
+  THE EXTENT APPLICABLE LAW PROHIBITS SUCH LIMITATION. SOME JURISDICTIONS DO 
NOT
+  ALLOW THE EXCLUSION OR LIMITATION OF INCIDENTAL OR CONSEQUENTIAL DAMAGES, SO
+  THIS EXCLUSION AND LIMITATION MAY NOT APPLY TO YOU.
+
+  8. U.S. GOVERNMENT END USERS. The Covered Software is a commercial item, as
+  that term is defined in 48 C.F.R. 2.101 (Oct. 1995), consisting of commercial
+  computer software (as that term is defined at 48 C.F.R.  252.227-7014(a)(1))
+  and commercial computer software documentation as such terms are used in 48
+  C.F.R. 12.212 (Sept. 1995). Consistent with 48 C.F.R. 12.212 and 48 C.F.R.
+  227.7202-1 through 227.7202-4 (June 1995), all U.S. Government End Users
+  acquire Covered Software with only those rights set forth herein. This U.S.
+  Government Rights clause is in lieu of, and supersedes, any other FAR, DFAR, 
or
+  other clause or provision that addresses Government rights in computer 
software
+  under this License.
+
+  9. MISCELLANEOUS. This License represents the complete agreement concerning
+  subject matter hereof. If any provision of this License is held to be
+  unenforceable, such provision shall be reformed only to the extent necessary 
to
+  make it enforceable. This License shall be governed by the law of the
+  jurisdiction specified in a notice contained within the Original Software
+  (except to the extent applicable law, if any, provides otherwise), excluding
+  such jurisdictions conflict-of-law provisions. Any litigation relating to 
this
+  License shall be subject to the jurisdiction of the courts located in the
+  jurisdiction and venue specified in a notice contained within the Original
+  Software, with the losing party responsible for costs, including, without
+  limitation, court costs and reasonable attorneys fees and expenses. The
+  application of the United Nations Convention on Contracts for the 
International
+  Sale of Goods is expressly excluded. Any law or regulation which provides 
that
+  the language of a contract shall be construed against the drafter shall not
+  apply to this License. You agree that You alone are responsible for 
compliance
+  with the United States export administration regulations (and the export
+  control laws and regulation of any other countries) when You use, distribute 
or
+  otherwise make available any Covered Software.
+
+  10. RESPONSIBILITY FOR CLAIMS. As between Initial Developer and the
+  Contributors, each party is responsible for claims and damages arising,
+  directly or indirectly, out of its utilization of rights under this License 
and
+  You agree to work with Initial Developer and Contributors to distribute such
+  responsibility on an equitable basis. Nothing herein is intended or shall be
+  deemed to constitute any admission of liability.
+
+  NOTICE PURSUANT TO SECTION 9 OF THE COMMON DEVELOPMENT AND DISTRIBUTION
+  LICENSE (CDDL) The code released under the CDDL shall be governed by the laws
+  of the State of California (excluding conflict-of-law provisions). Any
+  litigation relating to this License shall be subject to the jurisdiction of 
the
+  Federal Courts of the Northern District of California and the state courts of
+  the State of California, with venue lying in Santa Clara County, California.
 
 +++++++++++++++++++++++++++++
+

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/681cad66/licenses/lic-winodbc-bin
----------------------------------------------------------------------
diff --git a/licenses/lic-winodbc-bin b/licenses/lic-winodbc-bin
new file mode 100644
index 0000000..27ec643
--- /dev/null
+++ b/licenses/lic-winodbc-bin
@@ -0,0 +1,50 @@
+
+The Windows ODBC driver (TFODBC4) is removed from the binary distribution
+of Trafodion clients package.  This is due to inclusion of vcredist_x64.exe.
+See JIRA TRAFODION-1836.
+
+If the license issues with that software are resolved, and the driver is
+added back to the clients binary distribution package, then the license info
+below must be integrated back into lic-clients-bin file.
+
+This only affects binary distribution. This issue does not apply to the source
+distribution of win-odbc or derivative products.
+
+===============================================================================
+The binary distribution of Apache Trafodion bundles OpenSSL software. 
Specifically,
+the Linux ODBC driver is statically linked with OpenSSL libraries. The Windows
+ODBC driver (TFODBC64) also links in OpenSSL libraries.
+
+(Documented in licenses/lic-clients-bin.)
+
++++++++++++++++++++++++++++++
+
+The binary distribution of Apache Trafodion bundles zlib software. 
Specifically,
+the Windows ODBC driver (TFODBC64) links in zlib libraries. Zlib is 
+available under the zlib/libpng license.
+
+  zlib.h -- interface of the 'zlib' general purpose compression library
+  version 1.2.8, April 28th, 2013
+
+  Copyright (C) 1995-2013 Jean-loup Gailly and Mark Adler
+
+  This software is provided 'as-is', without any express or implied
+  warranty.  In no event will the authors be held liable for any damages
+  arising from the use of this software.
+
+  Permission is granted to anyone to use this software for any purpose,
+  including commercial applications, and to alter it and redistribute it
+  freely, subject to the following restrictions:
+
+  1. The origin of this software must not be misrepresented; you must not
+     claim that you wrote the original software. If you use this software
+     in a product, an acknowledgment in the product documentation would be
+     appreciated but is not required.
+  2. Altered source versions must be plainly marked as such, and must not be
+     misrepresented as being the original software.
+  3. This notice may not be removed or altered from any source distribution.
+
+  Jean-loup Gailly        Mark Adler
+  [email protected]          [email protected]
+
++++++++++++++++++++++++++++++

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/681cad66/licenses/not-dcs-bin
----------------------------------------------------------------------
diff --git a/licenses/not-dcs-bin b/licenses/not-dcs-bin
new file mode 100644
index 0000000..f5293e3
--- /dev/null
+++ b/licenses/not-dcs-bin
@@ -0,0 +1,20 @@
+
+Notices for Jython bundled software:
+
+   =========================================================================
+   ==  NOTICE file corresponding to section 4(d) of the Apache License,   ==
+   ==  Version 2.0, in this case for the Apache Xerces Java distribution. ==
+   =========================================================================
+
+   Apache Xerces Java
+   Copyright 1999-2007 The Apache Software Foundation
+
+   This product includes software developed at
+   The Apache Software Foundation (http://www.apache.org/).
+
+   Portions of this software were originally based on the following:
+     - software copyright (c) 1999, IBM Corporation., http://www.ibm.com.
+     - software copyright (c) 1999, Sun Microsystems., http://www.sun.com.
+     - voluntary contributions made by Paul Eng on behalf of the
+       Apache Software Foundation that were originally developed at iClick, 
Inc.,
+       software copyright (c) 1999.

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/681cad66/pom.xml
----------------------------------------------------------------------
diff --git a/pom.xml b/pom.xml
index f723602..7e2bf84 100644
--- a/pom.xml
+++ b/pom.xml
@@ -136,6 +136,8 @@
     <module>dcs</module>
     <module>core/rest</module>
     <module>docs/command_interface</module>
+    <module>docs/cqd_reference</module>
+    <module>docs/load_transform</module>
     <module>docs/provisioning_guide</module>
     <module>docs/messages_guide</module>
     <module>docs/odb_user</module>

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/681cad66/tools/docker/Dockerfile
----------------------------------------------------------------------
diff --git a/tools/docker/Dockerfile b/tools/docker/Dockerfile
new file mode 100644
index 0000000..be75b9b
--- /dev/null
+++ b/tools/docker/Dockerfile
@@ -0,0 +1,45 @@
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+FROM centos:centos6.6
+MAINTAINER Trafodion Community <[email protected]>
+
+LABEL Vendor="Apache Trafodion (incubating)"
+LABEL version=unstable
+
+# download and install environment dependencies
+RUN    yum install -y epel-release alsa-lib-devel ant ant-nodeps boost-devel 
cmake \
+            device-mapper-multipath dhcp flex gcc-c++ gd git glibc-devel \
+       glibc-devel.i686 graphviz-perl gzip java-1.7.0-openjdk-devel \
+                apr-devel apr-util-devel \
+       libX11-devel libXau-devel libaio-devel \
+       libcurl-devel libibcm.i686 libibumad-devel libibumad-devel.i686 \
+       libiodbc libiodbc-devel librdmacm-devel librdmacm-devel.i686 \
+       libxml2-devel lua-devel lzo-minilzo \
+       net-snmp-devel net-snmp-perl openldap-clients openldap-devel \
+       openldap-devel.i686 openmotif openssl-devel openssl-devel.i686 \
+       openssl-static perl-Config-IniFiles perl-Config-Tiny \
+       perl-DBD-SQLite perl-Expect perl-IO-Tty perl-Math-Calc-Units \
+       perl-Params-Validate perl-Parse-RecDescent perl-TermReadKey \
+       perl-Time-HiRes protobuf-compiler protobuf-devel \
+       readline-devel saslwrapper sqlite-devel \
+       unixODBC unixODBC-devel uuid-perl wget xerces-c-devel xinetd \
+  && yum -y erase pdsh \
+       && yum clean all
+
+# set environment
+ENV    JAVA_HOME /usr/lib/jvm/java-1.7.0-openjdk.x86_64
+ENV PATH $PATH:$JAVA_HOME/bin

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/681cad66/tools/docker/build-base-docker.sh
----------------------------------------------------------------------
diff --git a/tools/docker/build-base-docker.sh 
b/tools/docker/build-base-docker.sh
new file mode 100755
index 0000000..a280321
--- /dev/null
+++ b/tools/docker/build-base-docker.sh
@@ -0,0 +1,29 @@
+#!/bin/bash
+
+# Licensed to the Apache Software Foundation (ASF) under one or more
+# contributor license agreements.  See the NOTICE file distributed with
+# this work for additional information regarding copyright ownership.
+# The ASF licenses this file to You under the Apache License, Version 2.0
+# (the "License"); you may not use this file except in compliance with
+# the License.  You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+set -e -x -u
+
+BASE_SCRIPT_DIR=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )
+
+export DOCKER_ENV_VERSION="0.1"
+export BASE_IMAGE_NAME="trafodion/base:${DOCKER_ENV_VERSION}"
+
+pushd ${BASE_SCRIPT_DIR}
+
+docker build --rm=true -t ${BASE_IMAGE_NAME} .
+
+popd

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/681cad66/tools/docker/start-compile-docker.sh
----------------------------------------------------------------------
diff --git a/tools/docker/start-compile-docker.sh 
b/tools/docker/start-compile-docker.sh
new file mode 100755
index 0000000..f9697ec
--- /dev/null
+++ b/tools/docker/start-compile-docker.sh
@@ -0,0 +1,67 @@
+#!/bin/bash
+
+# Licensed to the Apache Software Foundation (ASF) under one or more
+# contributor license agreements.  See the NOTICE file distributed with
+# this work for additional information regarding copyright ownership.
+# The ASF licenses this file to You under the Apache License, Version 2.0
+# (the "License"); you may not use this file except in compliance with
+# the License.  You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+set -e -x -u
+
+SCRIPT_DIR=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )
+
+source ${SCRIPT_DIR}/build-base-docker.sh
+
+IMAGE_NAME="trafodion/base:${DOCKER_ENV_VERSION}"
+
+if [ "$(uname -s)" == "Linux" ]; then
+  USER_NAME=${SUDO_USER:=$USER}
+  USER_ID=$(id -u "${USER_NAME}")
+  GROUP_ID=$(id -g "${USER_NAME}")
+else # boot2docker uid and gid
+  USER_NAME=$USER
+  USER_ID=1000
+  GROUP_ID=50
+fi
+
+# create user home directory; download and install build tools
+docker build -t "${IMAGE_NAME}-${USER_NAME}" - <<UserSpecificDocker
+FROM ${IMAGE_NAME} 
+RUN groupadd --non-unique -g ${GROUP_ID} ${USER_NAME}
+RUN useradd -g ${GROUP_ID} -u ${USER_ID} -k /root -m ${USER_NAME}
+ENV HOME /home/${USER_NAME}
+RUN cd /home/${USER_NAME} \
+ && mkdir download \
+ && mkdir trafodion-build-tools \
+ && wget 
https://raw.githubusercontent.com/apache/incubator-trafodion/master/install/traf_tools_setup.sh
 \
+ && chmod +x traf_tools_setup.sh \
+ && ./traf_tools_setup.sh -d ~/download -i ~/trafodion-build-tools \
+ && rm -fr ./download \
+ && yum install -y qt-devel qt-config
+ENV TOOLSDIR /home/${USER_NAME}/trafodion-build-tools
+ENV PATH 
$PATH:/home/${USER_NAME}/trafodion-build-tools/apache-maven-3.3.3/bin:/usr/lib64/qt4/bin/
+UserSpecificDocker
+
+# Go to root project folder
+pushd ${SCRIPT_DIR}/../..
+
+docker run -i -t \
+  --rm=true \
+  -w "/home/${USER_NAME}/incubator-trafodion" \
+  -u "${USER_NAME}" \
+  -v "$PWD:/home/${USER_NAME}/incubator-trafodion" \
+  -v "$HOME/.m2:/home/${USER_NAME}/.m2" \
+  --name TrafodionEnv \
+  ${IMAGE_NAME}-${USER_NAME} \
+  bash
+
+popd

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/681cad66/wms/pom.xml
----------------------------------------------------------------------
diff --git a/wms/pom.xml b/wms/pom.xml
index 0080020..c79985c 100644
--- a/wms/pom.xml
+++ b/wms/pom.xml
@@ -381,7 +381,7 @@
        
        
        <!-- Dependencies -->
-       <hadoop.version>2.6.0</hadoop.version>   
+       <hadoop.version>${env.HADOOP_DEP_VER}</hadoop.version>   
        <commons-cli.version>1.2</commons-cli.version>
        <commons-codec.version>1.4</commons-codec.version>
        <commons-io.version>2.1</commons-io.version>

Reply via email to
diff --git a/install/traf_tools_setup.sh b/install/traf_tools_setup.sh
index 84a4825..956cd59 100755
--- a/install/traf_tools_setup.sh
+++ b/install/traf_tools_setup.sh
@@ -45,6 +45,7 @@
 # Thrift: Communications and data serialization tool
 # Maven: Build tool that is only installed if compatible version does not exist
 # log4cxx: standard logging framework for C++
+# hadoop: shared libraries for libhadoop, libhdfs, and hdfs header file
 #
 # Script can be modified to meet the needs of your environment
 # May need root or SUDO access to install tools in desired location
@@ -65,29 +66,26 @@ function Usage {
 
 # -----------------------------------------------------------------------------
 # function: downloadSource - downloads and un-tars the requested file
 #    $1 - tar file to download 
 #    $2 - directory where source is untarred
 #
-# Suggestion:  instead use a single argument $1 and figure out the name of the
-#              file to extract with basename $1
 # -----------------------------------------------------------------------------
 function downloadSource
 {
-  # currently only tar files ending in "tar.gz" and "tgz" are recognized
-  TARSUFFIX="tar.gz"
-  if [[ ! $1 == *$"$TARSUFFIX" ]]; then
-    TARSUFFIX="tgz"
-  fi
+  URL="$1"
+  SRCDIR="$2"
+  TARFILE="${URL##*/}"
 
-  if [ ! -e $BASEDIR/$2.$TARSUFFIX ]; then
-    wget $1  >>$LOGFILE 2>&1
+  if [ ! -e $BASEDIR/$TARFILE ]; then
+    wget $URL  >>$LOGFILE 2>&1
+    echo "INFO:   downloaded tar file: $TARFILE " | tee -a $LOGFILE
   else
-    echo "INFO:   tar file already downloaded, step skipped" | tee -a $LOGFIL
+    echo "INFO:   tar file already downloaded, step skipped" | tee -a $LOGFILE
   fi
 
-  if [ ! -e $BASEDIR/$2 ]; then
-    tar -xzf $BASEDIR/$2.$TARSUFFIX
-    echo "INFO:   downloaded tar file: $2.$TARSUFFIX " | tee -a $LOGFILE
+  if [ ! -e $BASEDIR/$SRCDIR ]; then
+    cd $BASEDIR
+    tar -xzf $BASEDIR/$TARFILE
   else
     echo "INFO:   source tree already exists" | tee -a $LOGFILE
   fi
@@ -156,6 +154,11 @@ if [ "$BASEDIR" == "" ]; then
   Usage;
   exit 1;
 fi
+# handle relative path
+if [[ ! $BASEDIR =~ ^/ ]]
+then
+  BASEDIR=$(pwd)/$BASEDIR
+fi
 
 if [ ! -d "$BASEDIR" ]; then
   echo
@@ -170,6 +173,11 @@ if [ "$TOOLSDIR" == "" ]; then
   Usage;
   exit 1;
 fi
+# handle relative path
+if [[ ! $TOOLSDIR =~ ^/ ]]
+then
+  TOOLSDIR=$(pwd)/$TOOLSDIR
+fi
 
 if [ ! -d "$TOOLSDIR" ]; then                                                  
  
   read -p "Tools install directory $TOOLSDIR does not exist, do you want to to 
create it? y/n : " CREATEDIR
@@ -401,6 +409,24 @@ else
 fi
 
 # -----------------------------------------------------------------------------
+# download hadoop/hdfs libs
+echo
+echo "INFO: Hadoop/HDFS libs on $(date)" | tee -a $LOGFILE
+HVER="2.6.0"
+if [ -d $TOOLSDIR/hadoop-${HVER} ]; then
+  echo "INFO: Hadoop/HDFS is already installed, skipping to next tool" | tee 
-a $LOGFILE
+else
+  downloadSource 
http://archive.apache.org/dist/hadoop/common/hadoop-${HVER}/hadoop-${HVER}.tar.gz
 # no un-tar
+  cd $TOOLSDIR
+  tar -xzf $BASEDIR/hadoop-${HVER}.tar.gz \
+    hadoop-${HVER}/lib/native/libhadoop\*so\* \
+    hadoop-${HVER}/lib/native/libhdfs\*so\* \
+    hadoop-${HVER}/include/hdfs.h
+  echo "INFO:   extraction complete" | tee -a $LOGFILE
+fi
+echo " *********************************************************** " | tee -a 
$LOGFILE
+
+# -----------------------------------------------------------------------------
 
 echo
 echo "INFO: Waiting for all background builds. This might take a while." | tee 
-a $LOGFILE

http://git-wip-us.apache.org/repos/asf/incubator-trafodion/blob/681cad66/licenses/lic-clients-bin
----------------------------------------------------------------------
@@ -65,29 +66,26 @@ function Usage {
 # -----------------------------------------------------------------------------
 # function: downloadSource - downloads and un-tars the requested file
-#    $1 - tar file to download 
-#    $2 - directory where source is untarred
+#    $1 - tar file URL to download
+#    $2 - directory where source is untarred (leave empty to skip untar)
 #